********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************


*****************************************************************
*****************************************************************
*Table B1: Relevance and exogeneity of the instrumental variables
*****************************************************************
*****************************************************************

use "Dataset 1 - cadastre1315.dta", clear

collapse Kura_settlementdum Kura_holy_family Kura_urbanpop300 Kura_military600 mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert, by(Kura_Code)


label variable Kura_DistancetoArish "\textit{Kura}'s distance to \\\textit{Arish} (km)"
label variable Kura_borderdesert "=1 if \textit{Kura} \\borders desert"
label variable Kura_distarishborddesert "Bordering desert \$\times\$ \\Dist. \textit{Arish}"


foreach x in Kura_settlementdum Kura_holy_family Kura_urbanpop300 Kura_military600 mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall {
quietly reg `x' Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert, robust
estimates store `x'
}

	
	
esttab Kura_settlementdum Kura_holy_family Kura_urbanpop300 Kura_military600 mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall using TableB1.tex, ///
replace booktabs nogaps cells(b(fmt(3)) se(fmt(3) star par)) collabels(none) ///
label se r2 star(* 0.10 ** 0.05 *** 0.01) nonotes noconstant ///
mtitles("\specialcell{=1 if Arab\\settlement\\in 700--969}" "\specialcell{=1 if Holy\\Family\\visit}" "\specialcell{Log (urban\\population)\\in 300}" "\specialcell{=1 if Byzantine\\garrison\\in 600}" "\specialcell{FAO-GAEZ\\cereals\\suitability}" "\specialcell{Mean\\temperature}" "\specialcell{Mean\\Temperature\\range}" "\specialcell{Mean\\slope}" "\specialcell{Mean\\rainfall}")



********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************

*************************************************************************************************************************
*************************************************************************************************************************
*Table B2: Local determinants of conversions to Islam in 641-1200 and total tax transfer in 1375: No region fixed effects
*************************************************************************************************************************
*************************************************************************************************************************

*Panel (a): Dependent variable: =1 if no Coptic church or monastery in village j circa 1200

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall

quietly reg nochurchmonast1200dum Kura_settlementdum, cluster(Kura_Code)
estimates store reg1
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg1

quietly reg nochurchmonast1200dum holy_family, cluster(Kura_Code)
estimates store reg2
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if holy_family == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg2


quietly reg nochurchmonast1200dum Kura_settlementdum holy_family, cluster(Kura_Code)
estimates store reg3
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg3


quietly reg nochurchmonast1200dum Kura_settlementdum holy_family `byzantinecontrols', cluster(Kura_Code)
estimates store reg4
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg4


quietly reg nochurchmonast1200dum Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols', cluster(Kura_Code)
estimates store reg5
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg5


quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert), first savefirst savefprefix(reg6) cluster(Kura_Code)

est store reg6
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg6

quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family, first savefirst savefprefix(reg7) cluster(Kura_Code)

est store reg7
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg7

quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols', first savefirst savefprefix(reg8) cluster(Kura_Code)

est store reg8
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg8


quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols', first savefirst savefprefix(reg9) cluster(Kura_Code)

est store reg9
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg9


esttab reg1 reg2 reg3 reg4 reg5 reg6 reg7 reg8 reg9 using TableB2a.tex, replace booktabs nogaps noconstant ///
cells(b(fmt(2)) se(fmt(2) star par)) collabels(none) star(* 0.10 ** 0.05 *** 0.01) ///
indicate("Byzantine controls? = Kura_urbanpop300 Kura_military600" "Geographic controls? = mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall") ///
stats(Obs Clusters R2 meany KP_Wald_Fstat, fmt(0 0 2 2 2) label ("Obs (villages)" "Clusters (\textit{kuras})" "\$R^2\$" "Mean dep. var. in control" "KP Wald \$F\$-stat")) label se nonotes ///
mtitles("OLS" "OLS" "OLS" "OLS" "OLS" "2SLS" "2SLS" "2SLS" "2SLS") ///
order(Kura_settlementdum holy_family) substitute(\_ _)


*Panel (b): Dependent variable: Tax transfer (ibra) in army dinars per unit of land in 1375
 
use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall
local popcontrol pop1897perfed

quietly reg ibraperfed1375 Kura_settlementdum, cluster(Kura_Code)
estimates store reg1
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg1

quietly reg ibraperfed1375 holy_family, cluster(Kura_Code)
estimates store reg2
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if holy_family == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg2


quietly reg ibraperfed1375 Kura_settlementdum holy_family, cluster(Kura_Code)
estimates store reg3
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg3

quietly reg ibraperfed1375 Kura_settlementdum holy_family `byzantinecontrols', cluster(Kura_Code)
estimates store reg4
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg4

quietly reg ibraperfed1375 Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols' `popcontrol', cluster(Kura_Code)
estimates store reg5
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg5

quietly ivreg2 ibraperfed1375 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert), first savefirst savefprefix(reg6) cluster(Kura_Code)

est store reg6
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg6


quietly ivreg2 ibraperfed1375 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family, first savefirst savefprefix(reg7) cluster(Kura_Code)

est store reg7
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg7


quietly ivreg2 ibraperfed1375 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols', first savefirst savefprefix(reg8) cluster(Kura_Code)

est store reg8
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg8


quietly ivreg2 ibraperfed1375 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols' `popcontrol', first savefirst savefprefix(reg1) cluster(Kura_Code)

est store reg9
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg9

esttab reg1 reg2 reg3 reg4 reg5 reg6 reg7 reg8 reg9 using TableB2b.tex, replace booktabs nogaps noconstant ///
cells(b(fmt(2)) se(fmt(2) star par)) collabels(none) star(* 0.10 ** 0.05 *** 0.01) ///
indicate("Byzantine controls? = Kura_urbanpop300 Kura_military600" "Geographic controls? = mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall" "Population per unit of land? = pop1897perfed") ///
stats(Obs Clusters R2 meany KP_Wald_Fstat, fmt(0 0 2 2 2) label ("Obs (villages)" "Clusters (\textit{kuras})" "\$R^2\$" "Mean dep. var. in control" "KP Wald \$F\$-stat")) label se nonotes ///
mtitles("OLS" "OLS" "OLS" "OLS" "OLS" "2SLS" "2SLS" "2SLS" "2SLS") ///
order(Kura_settlementdum holy_family) substitute(\_ _)



********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************


************************************************************************************************************
************************************************************************************************************
*Table B3: Local determinants of conversions to Islam in 641–1200: Robustness checks************************
*Dependent variable: =1 if no Coptic church or monastery in village j circa 1200 (except in columns (3)–(6))
************************************************************************************************************
************************************************************************************************************

*Columns (1)–(2): Amelineau's Byzantine-era villages only

use "Dataset 1 - cadastre1315.dta", clear

keep if amelineau_village == 1

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall

quietly reg nochurchmonast1200dum Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, cluster(Kura_Code)
estimates store reg1
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg1


quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, first savefirst savefprefix(reg9) cluster(Kura_Code)

est store reg2
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg2


*Columns (3)-(4): Dependent variable = 1 if no Coptic church or monastery in village circa 1500

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall


quietly reg nochurchmonast1500dum Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, cluster(Kura_Code)
estimates store reg3
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1500dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg3


quietly ivreg2 nochurchmonast1500dum (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, first savefirst savefprefix(reg9) cluster(Kura_Code)

est store reg4
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1500dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg4


*Columns (5)-(6): Dependent variable: =1 if Copt in 1848-1868

use "Dataset 3 - 1848_1868_population_census_samples_restricted.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall


quietly reg copt Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, cluster(Kura_Code)
estimates store reg5
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum copt if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg5

quietly ivreg2 copt (Kura_settlementdum = DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, first savefirst savefprefix(reg9) cluster(Kura_Code)

est store reg6
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum copt if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg6


*Columns (7)–(8): Control for interaction of Arab settlement and HF visit

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall

quietly reg nochurchmonast1200dum Kura_settlementdum holy_family settlementholyfamily `byzantinecontrols' `geographiccontrols' i.Kura_Region, cluster(Kura_Code)
estimates store reg7
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg7


quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum settlementholyfamily = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert interaction1 interaction2 interaction3) holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, first savefirst savefprefix(reg6) cluster(Kura_Code)
estimates store reg8
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg8



*Columns (9)–(10): Control for autopract status circa 600

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"
label variable Kura_Autopract "=1 if \textit{autopract} c. 600"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall

quietly reg nochurchmonast1200dum Kura_settlementdum holy_family Kura_Autopract `byzantinecontrols' `geographiccontrols', cluster(Kura_Code)
estimates store reg9
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg9


quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish) holy_family Kura_Autopract `byzantinecontrols' `geographiccontrols', first savefirst savefprefix(reg9) cluster(Kura_Code)

est store reg10
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg10


*Columns (11)–(12): Alternative measure of Copt religiosity (saint-martyr) 

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable saint_martyr "=1 if saint-martyr (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall


quietly reg nochurchmonast1200dum Kura_settlementdum saint_martyr `byzantinecontrols' `geographiccontrols' i.Kura_Region, cluster(Kura_Code)
estimates store reg11
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg11


quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) saint_martyr `byzantinecontrols' `geographiccontrols' i.Kura_Region, first savefirst savefprefix(reg9) cluster(Kura_Code)

est store reg12
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg12


*Columns (13)–(14): Spatial-autoregressive model with spatial-autoregressive errors (SARAR) model

use "Dataset 1 - cadastre1315.dta", clear

drop if longy == . | latx == .
bysort longy latx: keep if _n == 1


label variable nochurchmonast1200dum "=1 if no church in 1200"
label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"


spmat idistance WMat longy latx, id(code_1897n) replace

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall

xi: spreg  gs2sls nochurchmonast1200dum Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, id(code_1897n)  dlmat(WMat) 
estimates store reg13
quietly estadd scalar Obs = e(N)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg13


xi: spivreg nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, id(code_1897n) dlmat(WMat) 
est store reg14
quietly estadd scalar Obs = e(N)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg14


esttab reg1 reg2 reg3 reg4 reg5 reg6 reg7 reg8 reg9 reg10 reg11 reg12 reg13 reg14 using TableB3.tex, replace booktabs nogaps noconstant modelwidth(0) ///
cells(b(fmt(2)) se(fmt(2) star par)) collabels(none) star(* 0.10 ** 0.05 *** 0.01) ///
rename(_IKura_Regi_3 3.Kura_Region _IKura_Regi_4 4.Kura_Region _IKura_Regi_5 5.Kura_Region) ///
indicate("Region FE? = *.Kura_Region" "Byzantine controls? = Kura_urbanpop300 Kura_military600" "Geographic controls? = mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall") ///
stats(Obs Clusters R2 meany KP_Wald_Fstat, fmt(0 0 2 2 2) label ("Obs (villages)" "Clusters (\textit{kuras})" "\$R^2\$" "Mean dep. var. in control" "KP Wald \$F\$-stat")) label se nonotes ///
mgroups("\specialcell{Amélineau's\\Byzantine-era\\villages}" "\specialcell{=1 if no\\church or mon.\\c. 1500}" "\specialcell{=1 if Copt\\in 1848–1868}" ///
"\specialcell{Control\\interaction\\(\$c_i \times r_{ji}\$)}" "\specialcell{Control\\\textit{autopract}\\c. 600}" "\specialcell{Alternative\\measure of \$r_{ji}\$\\(Saint-martyr)}" ///
"\specialcell{SARAR model}", pattern(1 0 1 0 1 0 1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
mtitles("OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS") ///
coeflabel(Kura_settlementdum "=1 if Arab settlement (\$c_i\$)" ///
holy_family "=1 if HF visit (\$r_{ji}\$)" ///
settlementholyfamily "\$c_i\$ \$\times\$ \$r_{ji}\$" ///
Kura_Autopract "=1 if \textit{autopract} c. 600" ///
saint_martyr_synaxure "=1 if saint-martyr (\$r_{ji}\$)") ///
order(Kura_settlementdum holy_family settlementholyfamily Kura_Autopract saint_martyr) substitute(\_ _)


********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************


********************************************************************************	
********************************************************************************	
*Table B4: Evaluating the national representativeness of the poll tax sub-sample
********************************************************************************	
********************************************************************************	

*Panel (a): Village-level variables

use "Dataset 1 - cadastre1315.dta", clear

label variable nochurchmonast1200dum "=1 if no church or monastery in 1200"
label variable nochurchmonast1500dum "=1 if no church or monastery in 1500"
label variable ibraperfed1375 "\textit{ibra} per \textit{feddan} in 1375"
label variable ibraperfed1477 "\textit{ibra} per \textit{feddan} in 1477"
label variable holy_family "=1 if on H. Family route"
label variable saint_martyr "=1 if pre-641 Coptic saint or martyr"
label variable mean_cereals_index "FAO-GAEZ cereals suitability index"
label variable mean_tempmean "Mean temperature"
label variable mean_temprange "Mean temperature range"
label variable mean_slope "Mean slope"
label variable mean_rainfall "Mean rainfall"

global MAINVARS nochurchmonast1200dum nochurchmonast1500dum ibraperfed1375 ibraperfed1477 holy_family saint_martyr mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall
mata: mata clear

*First: Test of differences
local i = 1

foreach var in $MAINVARS {
    reg `var' polltaxsubsample, vce(cluster Kura_Code)
    outreg, keep(polltaxsubsample) rtitle("`: var label `var''") stats(b) ///
        noautosumm store(row`i') starlevels(10 5 1) starloc(1)
    outreg, replay(diff) append(row`i') ctitles("",Difference ) ///
        store(diff) note("")
    local ++i
}
outreg, replay(diff)


*Second: Summary statistics
local count: word count $MAINVARS
mat sumstat = J(`count',6,.)

local i = 1
foreach var in $MAINVARS {
    quietly: summarize `var' if polltaxsubsample==0
    mat sumstat[`i',1] = r(N)
    mat sumstat[`i',2] = r(mean)
    mat sumstat[`i',3] = r(sd)
    quietly: summarize `var' if polltaxsubsample==1
    mat sumstat[`i',4] = r(N)
    mat sumstat[`i',5] = r(mean)
    mat sumstat[`i',6] = r(sd)
    local i = `i' + 1
}
frmttable, statmat(sumstat) store(sumstat) sfmt(g,f,f,g,f,f)


outreg using "TableB4a.tex", ///
    replay(sumstat) merge(diff) tex nocenter note("") fragment plain replace ///
    ctitles("", Villages out of poll-tax sample, "", "", Villages in poll-tax sample, "", "", "" \ "", N, Mean, SD, N, Mean, SD, Diff) ///
    multicol(1,2,3;1,5,3)
	

*Panel (b): Kura-level variables

label variable Kura_settlementdum "=1 if Arab settlement in 700--969"
label variable Kura_urbanpop300 "Log (urban population) in 300"
label variable Kura_military600 "=1 if Byzantine garrison in 600"
label variable Kura_DistancetoArish "\textit{Kura}'s distance to \textit{Arish} (km)"
label variable Kura_borderdesert "=1 if \textit{Kura} borders desert"

bysort Kura_Code: keep if _n ==1
global MAINVARS Kura_settlementdum Kura_urbanpop300 Kura_military600 Kura_DistancetoArish Kura_borderdesert
mata: mata clear

*First: Test of differences
local i = 1

foreach var in $MAINVARS {
    reg `var' polltaxsubsample, robust
    outreg, keep(polltaxsubsample) rtitle("`: var label `var''") stats(b) ///
        noautosumm store(row`i') starlevels(10 5 1) starloc(1)
    outreg, replay(diff) append(row`i') ctitles("",Difference ) ///
        store(diff) note("")
    local ++i
}
outreg, replay(diff)


*Second: Summary statistics
local count: word count $MAINVARS
mat sumstat = J(`count',6,.)

local i = 1
foreach var in $MAINVARS {
    quietly: summarize `var' if polltaxsubsample==0
    mat sumstat[`i',1] = r(N)
    mat sumstat[`i',2] = r(mean)
    mat sumstat[`i',3] = r(sd)
    quietly: summarize `var' if polltaxsubsample==1
    mat sumstat[`i',4] = r(N)
    mat sumstat[`i',5] = r(mean)
    mat sumstat[`i',6] = r(sd)
    local i = `i' + 1
}
frmttable, statmat(sumstat) store(sumstat) sfmt(g,f,f,g,f,f)


outreg using "TableB4b.tex", ///
    replay(sumstat) merge(diff) tex nocenter note("") fragment plain replace ///
    ctitles("", Kuras out of poll-tax sample, "", "", Kuras in poll-tax sample, "", "", "" \ "", N, Mean, SD, N, Mean, SD, Diff) ///
    multicol(1,2,3;1,5,3)
	
	
	
*Panel (c): Dep. var. =1 if no Coptic church or monastery in village j c. 1200: Poll tax sub-sample


use "Dataset 1 - cadastre1315.dta", clear

keep if polltaxsubsample == 1

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall

local reg1 = "reg1"
eststo `reg1': quietly reg nochurchmonast1200dum Kura_settlementdum, cluster(Kura_Code)
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg1'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg1'
}


local reg2 = "reg2"
eststo `reg2': quietly reg nochurchmonast1200dum holy_family, cluster(Kura_Code)
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if holy_family == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg2'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg2'
}


local reg3 = "reg3"
eststo `reg3': quietly reg nochurchmonast1200dum Kura_settlementdum holy_family, cluster(Kura_Code)
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg3'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg3'
}


local reg4 = "reg4"
eststo `reg4': quietly reg nochurchmonast1200dum Kura_settlementdum holy_family `byzantinecontrols', cluster(Kura_Code)
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg4'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg4'
}


local reg5 = "reg5"
eststo `reg5': quietly reg nochurchmonast1200dum Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols', cluster(Kura_Code)
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg5'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg5'
}


local reg6 = "reg6"
eststo `reg6': quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish), first cluster(Kura_Code)

quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg6'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg6'
}


local reg7 = "reg7"
eststo `reg7': quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish) holy_family, first cluster(Kura_Code)

quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg7'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg7'
}


local reg8 = "reg8"
eststo `reg8': quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish) holy_family `byzantinecontrols', first cluster(Kura_Code)

quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg8'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg8'
}


local reg9 = "reg9"
eststo `reg9': quietly ivreg2 nochurchmonast1200dum (Kura_settlementdum = Kura_DistancetoArish) holy_family `byzantinecontrols' `geographiccontrols', first cluster(Kura_Code)

quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum nochurchmonast1200dum if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store `reg9'

*Run boottest to get bootstrapped clustered pvals for all coefficients
local indep_vars: colnames e(b)
local n_vars: colsof e(b)
local indep_hypotheses
foreach var of local indep_vars {
	local indep_hypotheses = "`indep_hypotheses' {`var'}"
}

boottest `indep_hypotheses', cluster(Kura_Code) reps (999) weight (webb) nograph //boottest each coefficient

*Store boottest output in e() matrices
matrix boot_pval  = J(1,`n_vars',.)
forval k = 1/`n_vars' { //Loop through predictors, aka matrix columns
	matrix boot_pval[1,`k'] = r(p_`k')
}
foreach mat in "boot_pval" {
	matrix colnames `mat' = `indep_vars'
	estadd matrix `mat' = `mat': `reg9'
}


esttab reg1 reg2 reg3 reg4 reg5 reg6 reg7 reg8 reg9 using TableB4c.tex, replace booktabs nogaps noconstant ///
cells(b(fmt(2)) boot_pval(fmt(2) par)) collabels(none) ///
indicate("Byzantine controls? = Kura_urbanpop300" "Geographic controls? = mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall") ///
stats(Obs Clusters R2 meany KP_Wald_Fstat, fmt(0 0 2 2 2) label ("Obs (villages)" "Clusters (\textit{kuras})" "\$R^2\$" "Mean dep. var. in control" "KP Wald \$F\$-stat")) label se nonotes ///
mtitles("OLS" "OLS" "OLS" "OLS" "OLS" "2SLS" "2SLS" "2SLS" "2SLS") ///
order(Kura_settlementdum holy_family) substitute(\_ _)


	

********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************



	
************************************************************************************************************
************************************************************************************************************
*Table B5: Local determinants of the total tax transfer in 1375: Robustness checks**************************
*Dependent variable: Tax transfer (ibra) in army dinars per unit of land in 1375 (except in columns (1)–(2))
************************************************************************************************************
************************************************************************************************************


*Columns (1)–(2): Dependent variable: Total tax transfer per unit of land in 1477

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"
 
local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall
local popcontrol pop1897perfed

quietly reg ibraperfed1477 Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols' `popcontrol' i.Kura_Region, cluster(Kura_Code)
estimates store reg1
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1477 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg1


quietly ivreg2 ibraperfed1477 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols' `popcontrol' i.Kura_Region, first savefirst savefprefix(reg1) cluster(Kura_Code)

est store reg2
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1477 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg2


*Columns (3)–(4): Province fixed effects with two-way clustering

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"
 
local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall
local popcontrol pop1897perfed


quietly reghdfe ibraperfed1375 Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols' `popcontrol' i.province_1315, noabsorb cluster(Kura_Code province_1315)
estimates store reg3
quietly estadd scalar Clusters = e(N_clust1)
quietly estadd scalar Clusters2 = e(N_clust2)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg3


quietly ivreg2 ibraperfed1375 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols' `popcontrol' i.province_1315, first savefirst savefprefix(reg1) cluster(Kura_Code province_1315)
est store reg4
quietly estadd scalar Clusters = e(N_clust1)
quietly estadd scalar Clusters2 = e(N_clust2)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg4


*Columns (5)–(6): Control for interaction of Arab settlement and HF visit

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall
local popcontrol pop1897perfed


quietly reg ibraperfed1375 Kura_settlementdum holy_family settlementholyfamily `byzantinecontrols' `geographiccontrols' i.Kura_Region, cluster(Kura_Code)
estimates store reg5
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg5

quietly ivreg2 ibraperfed1375 (Kura_settlementdum settlementholyfamily = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert interaction1 interaction2 interaction3) holy_family `byzantinecontrols' `geographiccontrols' i.Kura_Region, first savefirst savefprefix(reg6) cluster(Kura_Code)
estimates store reg6
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg6


*Columns (7)–(8): Control for Mamluk LA in 1375
 
use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"
label variable taxcontractortopofficial1375 "=1 if LA in 1375 Mamluk"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall
local popcontrol pop1897perfed


quietly reg ibraperfed1375 Kura_settlementdum holy_family taxcontractortopofficial1375 `byzantinecontrols' `geographiccontrols' `popcontrol' i.Kura_Region, cluster(Kura_Code)
estimates store reg7
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg7

quietly ivreg2 ibraperfed1375 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family taxcontractortopofficial1375 `byzantinecontrols' `geographiccontrols' `popcontrol' i.Kura_Region, first savefirst savefprefix(reg1) cluster(Kura_Code)
est store reg8
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg8



*Columns (9)–(10): Alternative measure of Copt religiosity (saint-martyr)

use "Dataset 1 - cadastre1315.dta", clear

label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable saint_martyr "=1 if saint-martyr (\$r_{ji}\$)"

local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall
local popcontrol pop1897perfed


quietly reg ibraperfed1375 Kura_settlementdum saint_martyr `byzantinecontrols' `geographiccontrols' `popcontrol' i.Kura_Region, cluster(Kura_Code)
estimates store reg9
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg9

quietly ivreg2 ibraperfed1375 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) saint_martyr `byzantinecontrols' `geographiccontrols' `popcontrol' i.Kura_Region, first savefirst savefprefix(reg1) cluster(Kura_Code)
est store reg10
quietly estadd scalar Clusters = e(N_clust)
quietly estadd scalar Obs = e(N)
quietly estadd scalar R2 = e(r2)
quietly estadd scalar KP_Wald_Fstat=e(widstat)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg10



*Columns (11)–(12): Spatial-autoregressive model with spatial-autoregressive errors (SARAR) model

use "Dataset 1 - cadastre1315.dta", clear

drop if longy == . | latx == .
drop if ibraperfed1375 == . | Kura_settlementdum == . | holy_family== . | Kura_urbanpop300 == . | Kura_military600 == . |  mean_cereals_index == . | mean_tempmean == . |  mean_temprange == . | mean_slope == . | mean_rainfall == . | pop1897perfed == . |  province_1315 == .
bysort longy latx: keep if _n == 1

label variable ibraperfed1375 "Tax transfer in 1375"
label variable Kura_settlementdum "=1 if Arab settlement (\$c_i\$)"
label variable holy_family "=1 if HF visit (\$r_{ji}\$)"


local byzantinecontrols Kura_urbanpop300 Kura_military600
local geographiccontrols mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall
local popcontrol pop1897perfed

spmat idistance WMat longy latx, id(code_1897n) replace


xi: spreg  gs2sls ibraperfed1375 Kura_settlementdum holy_family `byzantinecontrols' `geographiccontrols' `popcontrol' i.Kura_Region, id(code_1897n)  dlmat(WMat) 
estimates store reg11
quietly estadd scalar Obs = e(N)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg11

xi: spivreg ibraperfed1375 (Kura_settlementdum = Kura_DistancetoArish Kura_borderdesert Kura_distarishborddesert) holy_family `byzantinecontrols' `geographiccontrols' `popcontrol' i.Kura_Region, id(code_1897n)  dlmat(WMat) 
est store reg12
quietly estadd scalar Obs = e(N)
quietly sum ibraperfed1375 if Kura_settlementdum == 0
local meany = r(mean)
quietly estadd scalar meany = `meany'
est store reg12


esttab reg1 reg2 reg3 reg4 reg5 reg6 reg7 reg8 reg9 reg10 reg11 reg12 using TableB5.tex, replace booktabs nogaps noconstant modelwidth(0) ///
cells(b(fmt(2)) se(fmt(2) star par)) collabels(none) star(* 0.10 ** 0.05 *** 0.01) ///
rename(_IKura_Regi_3 3.Kura_Region _IKura_Regi_4 4.Kura_Region _IKura_Regi_5 5.Kura_Region) ///
indicate("Region FE? = *.Kura_Region" "Province FE? = *.province_1315" "Byzantine controls? = Kura_urbanpop300 Kura_military600" "Geographic controls? = mean_cereals_index mean_tempmean mean_temprange mean_slope mean_rainfall" "Population per unit of land? = pop1897perfed") ///
stats(Obs Clusters Clusters2 R2 meany KP_Wald_Fstat, fmt(0 0 0 2 2 2) label ("Obs (villages)" "Clusters (\textit{kuras})" "Clusters (provinces)" "\$R^2\$" "Mean dep. var. in control" "KP Wald \$F\$-stat")) label se nonotes ///
mgroups("\specialcell{Tax transfer\\in 1477}" "\specialcell{Province FE\\two-way\\clustering}" ///
"\specialcell{Control\\interaction\\(\$c_i \times r_{ji}\$)}" "\specialcell{Control\\Mamluk LA\\in 1375}" ///
"\specialcell{Alternative\\measure of \$r_{ji}\$\\(Saint-martyr)}" ///
"\specialcell{SARAR model}", pattern(1 0 1 0 1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
mtitles("OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS" "OLS" "2SLS") ///
coeflabel(Kura_settlementdum "=1 if Arab settlement (\$c_i\$)" ///
holy_family "=1 if HF visit (\$r_{ji}\$)" ///
settlementholyfamily "\$c_i\$ \$\times\$ \$r_{ji}\$" ///
taxcontractortopofficial1375 "=1 if LA in 1375 Mamluk" ///
saint_martyr "=1 if saint-martyr (\$r_{ji}\$)") ///
order(Kura_settlementdum holy_family settlementholyfamily taxcontractortopofficial1375 saint_martyr) substitute(\_ _)




********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************
********************************************************************************************************************************



	
*********************************************************************************************************
*********************************************************************************************************
*Table B6: Time-series determinants of poll tax hikes and conversion waves in 641–1170: Robustness checks
*********************************************************************************************************
*********************************************************************************************************


*Columns (1)–(3): Governor-level dataset

use "Dataset 5 - Governors_641_1170.dta", clear


foreach outcome of varlist polltaxrise conversions{

local identitystrengthgov 1.gov_hostile_samehigh_hist
local govhostilenprevious gov_hostile_nprevious
local controlsext foreign_attacks nileshock
local timegov gov_start_date_norm

quietly reg `outcome' `identitystrengthgov' `govhostilenprevious' [aweight = governor_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthgov' `govhostilenprevious' [aweight = governor_nyears], lag(15)
estimates store reg1`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg1`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg1`outcome'

quietly reg `outcome' `identitystrengthgov' `govhostilenprevious' `timegov' [aweight = governor_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthgov' `govhostilenprevious' `timegov' [aweight = governor_nyears], lag(15)
estimates store reg2`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg2`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg2`outcome'

quietly reg `outcome' `identitystrengthgov' `govhostilenprevious' `controlsext' `timegov'  [aweight = governor_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthgov' `govhostilenprevious' `controlsext' `timegov' [aweight = governor_nyears], lag(15)
estimates store reg3`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg3`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg3`outcome'

}


*Controlling for the number of previous poll tax hikes

use "Dataset 4 - Caliphs_641_1170.dta", clear

foreach outcome of varlist polltaxrise conversions{

local identitystrengthcal 1.caliph_pious_samehigh_hist
local caltaxrisehist cal_taxrise_nprevious
local controlsext foreign_attacks nileshock
local timecal caliph_start_date_norm


quietly reg `outcome' `identitystrengthcal' `caltaxrisehist' [aweight = caliph_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthcal' `caltaxrisehist' [aweight = caliph_nyears], lag(11)
estimates store reg4`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg4`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg4`outcome'

quietly reg `outcome' `identitystrengthcal' `caltaxrisehist' `timecal' [aweight = caliph_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthcal' `caltaxrisehist' `timecal' [aweight = caliph_nyears], lag(11)
estimates store reg5`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg5`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg5`outcome'

quietly reg `outcome' `identitystrengthcal' `caltaxrisehist' `controlsext' `timecal'  [aweight = caliph_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthcal' `caltaxrisehist' `controlsext' `timecal' [aweight = caliph_nyears], lag(11)
estimates store reg6`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg6`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg6`outcome'

}



*Interaction of Caliph piety and the number of previous pious Caliphs

use "Dataset 4 - Caliphs_641_1170.dta", clear

foreach outcome of varlist polltaxrise conversions{

local identitystrengthcal 1.caliph_pious_samehigh_hist
local calpiousnprevious caliph_pious_nprevious
local interaction interaction
local controlsext foreign_attacks nileshock
local timecal caliph_start_date_norm


quietly reg `outcome' `identitystrengthcal' `calpiousnprevious' `interaction' [aweight = caliph_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthcal' `calpiousnprevious' `interaction' [aweight = caliph_nyears], lag(11)
estimates store reg7`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg7`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg7`outcome'

quietly reg `outcome' `identitystrengthcal' `calpiousnprevious' `interaction' `timecal' [aweight = caliph_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthcal' `calpiousnprevious' `interaction' `timecal' [aweight = caliph_nyears], lag(11)
estimates store reg8`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg8`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg8`outcome'

quietly reg `outcome' `identitystrengthcal' `calpiousnprevious' `interaction' `controlsext' `timecal'  [aweight = caliph_nyears]
local rsquared = e(r2)
quietly estat bgodfrey, lags(11)
local bgpvalue = r(p)[1,1]
quietly newey `outcome' `identitystrengthcal' `calpiousnprevious' `interaction' `controlsext' `timecal' [aweight = caliph_nyears], lag(11)
estimates store reg9`outcome'
quietly estadd scalar Obs = e(N)
quietly estadd scalar Years = 526
quietly estadd scalar R2 = `rsquared'
quietly estadd scalar bgpvalue = `bgpvalue'
estimates store reg9`outcome'
quietly sum `outcome'
local meany = r(mean)
quietly estadd scalar meany = `meany'
estimates store reg9`outcome'

}


esttab reg1polltaxrise reg2polltaxrise reg3polltaxrise reg4polltaxrise reg5polltaxrise reg6polltaxrise reg7polltaxrise reg8polltaxrise reg9polltaxrise using TableB6a.tex, replace booktabs nogaps noconstant ///
cells(b(fmt(2)) se(fmt(2) star par)) collabels(none) star(* 0.10 ** 0.05 *** 0.01) ///
stats(Obs Years R2 bgpvalue meany, fmt(0 0 2 2 2) label ("Obs (governors/Caliphs)" "Years" "\$R^2\$" "\$p\$-value (Breusch–Godfrey test)" "Mean dep. var.")) label se nonotes ///
rename(1.gov_hostile_samehigh_hist 1.caliph_pious_samehigh_hist, ///
gov_hostile_nprevious caliph_pious_nprevious ///
gov_start_date_norm caliph_start_date_norm) ///
keep(1.caliph_pious_samehigh_hist caliph_pious_nprevious cal_taxrise_nprevious interaction caliph_start_date_norm) ///
nomtitles substitute(\_ _) ///
indicate("Controls? = foreign_attacks nileshock") ///
mgroups("\specialcell{Governor-level dataset}" "\specialcell{Control n. prev. tax hikes}" "\specialcell{Control \$\hat{c}_t \times n^c_{t-1}\$}", pattern(1 0 0 1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
coeflabel(1.caliph_pious_samehigh_hist "=1 if ruler's identity strong (\$\hat{c}_t\$)" ///
caliph_pious_nprevious "N. prev. strong identity rulers (\$n^c_{t-1}\$)" ///
cal_taxrise_nprevious "N. previous poll tax hikes" ///
interaction "\$\hat{c}_t \times n^c_{t-1} \$" ///
caliph_start_date_norm "Ruler's start year") ///
order(1.caliph_pious_samehigh_hist caliph_pious_nprevious cal_taxrise_nprevious interaction caliph_start_date_norm) 

esttab reg1conversions reg2conversions reg3conversions reg4conversions reg5conversions reg6conversions reg7conversions reg8conversions reg9conversions using TableB6b.tex, replace booktabs nogaps noconstant ///
cells(b(fmt(2)) se(fmt(2) star par)) collabels(none) star(* 0.10 ** 0.05 *** 0.01) ///
stats(Obs Years R2 bgpvalue meany, fmt(0 0 2 2 2) label ("Obs (governors/Caliphs)" "Years" "\$R^2\$" "\$p\$-value (Breusch–Godfrey test)" "Mean dep. var.")) label se nonotes ///
rename(1.gov_hostile_samehigh_hist 1.caliph_pious_samehigh_hist, ///
gov_hostile_nprevious caliph_pious_nprevious ///
gov_start_date_norm caliph_start_date_norm) ///
keep(1.caliph_pious_samehigh_hist caliph_pious_nprevious cal_taxrise_nprevious interaction caliph_start_date_norm) ///
nomtitles substitute(\_ _) ///
indicate("Controls? = foreign_attacks nileshock") ///
mgroups("\specialcell{Governor-level dataset}" "\specialcell{Control n. prev. tax hikes}" "\specialcell{Control \$\hat{c}_t \times n^c_{t-1}\$}", pattern(1 0 0 1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span) ///
coeflabel(1.caliph_pious_samehigh_hist "=1 if ruler's identity strong (\$\hat{c}_t\$)" ///
caliph_pious_nprevious "N. prev. strong identity rulers (\$n^c_{t-1}\$)" ///
cal_taxrise_nprevious "N. prev. poll tax hikes" ///
interaction "\$\hat{c}_t \times n^c_{t-1} \$" ///
caliph_start_date_norm "Ruler's start year") ///
order(1.caliph_pious_samehigh_hist caliph_pious_nprevious cal_taxrise_nprevious interaction caliph_start_date_norm) 
